==> vtigercrm-5.3.0p0.tgz: modules/Home/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Home/language/en_us.lang.php,v 1.5 2005/03/04 15:18:47 jack Exp $
 * Description:  Defines the English language pack
 ********************************************************************************/

$mod_strings = Array(
'LBL_NEW_FORM_TITLE'=>'Novo Contato',
'LBL_FIRST_NAME'=>'Nome:',
'LBL_LAST_NAME'=>'Sobrenome:',
'LBL_LIST_LAST_NAME'=>'Sobrenome',
'LBL_ACCOUNT_NAME'=>'Nome da Conta:',
'LBL_LIST_ACCOUNT_NAME'=>'Nome da Conta',
'LBL_PHONE'=>'Telefone:',
'LBL_EMAIL_ADDRESS'=>'Email:',
'LBL_TOTAL'=>'Total : ',

'LBL_MY_HOME'=>'Minha Homepage',
'LBL_MODIFIED_TIME'=>'Data Modificação',
'LBL_LOGIN_ID'=>'ID',
'LBL_MODIFIED_BY'=>'Modificado por',
'LBL_TYPE'=>'Tipo',

'LBL_PIPELINE_FORM_TITLE'=>'Meu Funil Vendas',

'ERR_ONE_CHAR'=>'Por favor, entre com pelo menos uma letra ou número para sua pesquisa ...',

'LBL_OPEN_TASKS'=>'Tarefas Abertas',

'LBL_LEADS_BY_SOURCE'=>'Leads por Origem',
'LBL_LEADS_BY_STATUS'=>'Leads por Status',

'LBL_UPCOMING_EVENTS'=>'Eventos Programados',
'LBL_PENDING_EVENTS'=>'Eventos Pendentes',
'LBL_SINGLE_PENDING_EVENT'=>'Evento para Últimos Dez Dias',
'LBL_MULTIPLE_PENDING_EVENTS'=>'Eventos nos Últimos Dez Dias',

'recordsforuser'=>'Registros para',

'Today'=>'Hoje',
'This Week'=>'Esta Semana',
'This Month'=>'Este Mês',
'This Year'=>'Este Ano',
'Last Week'=>'Última Semana',
'Last 2 Days'=>'Últimos 2 Dias',
'Last Ten Days'=>'Últimos Dez Dias',

// Added/Updated for vtiger CRM 5.0.4
'TITLE_AJAX_CSS_POPUP_CHAT'=>'Janela-Css de Bate-Papo Ajax',
'User List'=>'Lista Usuários',

// Added after 5.0.4 GA

//ADDED for Home Page Customization
'LBL_HOME_MODULE' => 'Modulo',
'LBL_HOME_RSS' => 'RSS',
'LBL_HOME_DASHBOARD' => 'Painel',
'LBL_HOME_STUFFTITLE'=>'Título Janela',
'LBL_HOME_SHOW'=>'Mostrar',
'LBL_HOME_FILTERBY'=>'Filtrar por',
'LBL_HOME_Fields'=>'Campos para Mostrar <br>(no máximo dois)',
'LBL_HOME_PRESSCTRL'=>'(Aperte a tecla "Ctrl" <br> para seleção múltipla)',
'LBL_HOME_RSSURL'=>'URL RSS',
'LBL_HOME_DASHBOARD_NAME'=>'Nome Painel', 
'LBL_HOME_DASHBOARD_TYPE'=>'Tipo Painel',
'LBL_HOME_HORIZONTAL_BARCHART'=>'Gráfico Barras Horizontal',
'LBL_HOME_VERTICAL_BARCHART'=>'Gráfico Barras Vertical',
'LBL_HOME_PIE_CHART'=>'Gráfica Pizza',
'LBL_HOME_ITEMS'=>'item(s)',
'LBL_MORE'=>'Mais',
'LBL_SCROLL'=>'Rolar',

// vtiger CRM News
'LBL_NEWS_NO'=>'Nenhuma Novidade',

//added for home page changes
'LBL_NOTEBOOK'=>'Bloco Notas',
'LBL_NOTEBOOK_TITLE'=>'Duplo clique para editar.',
'LBL_NOTEBOOK_SAVE_TITLE'=>'Clique em qualquer lugar sobre a página para salvar.',

'LBL_URL'=>'Website',
'LBL_HOME_LAYOUT'=>'Mudar layout',
'LBL_NUMBER_OF_COLUMNS'=>'Número de Colunas',
'LBL_TWO_COLUMN'=>'Duas Colunas',
'LBL_THREE_COLUMN'=>'Três Colunas',
'LBL_FOUR_COLUMN'=>'Quatro Colunas',
// END

// Default home page widget's title
'Top Accounts'=>'Principais Contas',
'Top Potentials'=>'Principais Oportunidades',
'Top Quotes'=>'Principais Cotações',
'Top Trouble Tickets'=>'Principais Tickets',
'Top Invoices'=>'Principais Faturas',
'Top Sales Orders'=>'Principais Pedidos Vendas',
'Top Purchase Orders'=>'Principais Pedidos Compras',
'My New Leads'=>'Meus Novos Leads',
'Key Metrics'=>'Métricas Chave',
'My Group Allocation'=>'Meus Grupos',
'My Recent FAQs'=>'Minhas FAQs Recentes',
'Upcoming Activities'=>'Próximas Atividades',
'Pending Activities'=>'Atividades Pendentes',
'Home Page Dashboard'=>'Página Painel',
'Tag Cloud'=>'Tag Cloud',

'MSG_NO_FILTERS' => 'Nenhum Filtro Disponível',
'MSG_NO_FIELDS' => 'Nenhum Campo Disponível',

);

?>

==> vtigercrm-5.4.0.tgz: modules/Home/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Home/language/en_us.lang.php,v 1.5 2005/03/04 15:18:47 jack Exp $
 * Description:  Defines the English language pack for Home Module.
 ********************************************************************************/

$mod_strings = Array(
'LBL_NEW_FORM_TITLE'=>'Novo Contato',
'LBL_FIRST_NAME'=>'Nome:',
'LBL_LAST_NAME'=>'Sobrenome:',
'LBL_LIST_LAST_NAME'=>'Sobrenome',
'LBL_ACCOUNT_NAME'=>'Nome da Organização:',
'LBL_LIST_ACCOUNT_NAME'=>'Nome da Organização',
'LBL_PHONE'=>'Telefone:',
'LBL_EMAIL_ADDRESS'=>'Email:',
'LBL_TOTAL'=>'Total : ',

'LBL_MY_HOME'=>'Minha Homepage',
'LBL_MODIFIED_TIME'=>'Data Modificação',
'LBL_LOGIN_ID'=>'ID',
'LBL_MODIFIED_BY'=>'Modificado por',
'LBL_TYPE'=>'Tipo',

'LBL_PIPELINE_FORM_TITLE'=>'Meu Funil Vendas',

'ERR_ONE_CHAR'=>'Por favor, entre com pelo menos uma letra ou número para sua pesquisa ...',

'LBL_OPEN_TASKS'=>'Tarefas Abertas',

'LBL_LEADS_BY_SOURCE'=>'Leads por Origem',
'LBL_LEADS_BY_STATUS'=>'Leads por Status',

'LBL_UPCOMING_EVENTS'=>'Eventos Programados',
'LBL_PENDING_EVENTS'=>'Eventos Pendentes',
'LBL_SINGLE_PENDING_EVENT'=>'Evento para Últimos Dez Dias',
'LBL_MULTIPLE_PENDING_EVENTS'=>'Eventos nos Últimos Dez Dias',

'recordsforuser'=>'Registros para',

'Today'=>'Hoje',
'This Week'=>'Esta Semana',
'This Month'=>'Este Mês',
'This Year'=>'Este Ano',
'Last Week'=>'Última Semana',
'Last 2 Days'=>'Últimos 2 Dias',
'Last Ten Days'=>'Últimos Dez Dias',

// Added/Updated for vtiger CRM 5.0.4
'TITLE_AJAX_CSS_POPUP_CHAT'=>'Janela-Css de Bate-Papo Ajax',
'User List'=>'Lista Usuários',

// Added after 5.0.4 GA

//ADDED for Home Page Customization
'LBL_HOME_MODULE' => 'Modulo',
'LBL_HOME_RSS' => 'RSS',
'LBL_HOME_DASHBOARD' => 'Painel',
'LBL_HOME_STUFFTITLE'=>'Título Janela',
'LBL_HOME_SHOW'=>'Mostrar',
'LBL_HOME_FILTERBY'=>'Filtrar por',
'LBL_HOME_Fields'=>'Campos para Mostrar <br>(no máximo dois)',
'LBL_HOME_PRESSCTRL'=>'(Aperte a tecla "Ctrl" <br> para seleção múltipla)',
'LBL_HOME_RSSURL'=>'URL RSS',
'LBL_HOME_DASHBOARD_NAME'=>'Nome Painel', 
'LBL_HOME_DASHBOARD_TYPE'=>'Tipo Painel',
'LBL_HOME_HORIZONTAL_BARCHART'=>'Gráfico Barras Horizontal',
'LBL_HOME_VERTICAL_BARCHART'=>'Gráfico Barras Vertical',
'LBL_HOME_PIE_CHART'=>'Gráfica Pizza',
'LBL_HOME_ITEMS'=>'item(s)',
'LBL_MORE'=>'Mais',
'LBL_SCROLL'=>'Rolar',

// vtiger CRM News
'LBL_NEWS_NO'=>'Nenhuma Novidade',

//added for home page changes
'LBL_NOTEBOOK'=>'Bloco Notas',
'LBL_NOTEBOOK_TITLE'=>'Duplo clique para editar.',
'LBL_NOTEBOOK_SAVE_TITLE'=>'Clique em qualquer lugar sobre a página para salvar.',

'LBL_URL'=>'Website',
'LBL_HOME_LAYOUT'=>'Mudar layout',
'LBL_NUMBER_OF_COLUMNS'=>'Número de Colunas',
'LBL_TWO_COLUMN'=>'Duas Colunas',
'LBL_THREE_COLUMN'=>'Três Colunas',
'LBL_FOUR_COLUMN'=>'Quatro Colunas',
// END

// Default home page widget's title
'Top Accounts'=>'Principais Organizações',
'Top Potentials'=>'Principais Oportunidades',
'Top Quotes'=>'Principais Cotações',
'Top Trouble Tickets'=>'Principais Tickets',
'Top Invoices'=>'Principais Faturas',
'Top Sales Orders'=>'Principais Pedidos Vendas',
'Top Purchase Orders'=>'Principais Pedidos Compras',
'My New Leads'=>'Meus Novos Leads',
'Key Metrics'=>'Métricas Chave',
'My Group Allocation'=>'Meus Grupos',
'My Recent FAQs'=>'Minhas FAQs Recentes',
'Upcoming Activities'=>'Próximas Atividades',
'Pending Activities'=>'Atividades Pendentes',
'Home Page Dashboard'=>'Página Painel',
'Tag Cloud'=>'Tag Cloud',

'MSG_NO_FILTERS' => 'Nenhum Filtro Disponível',
'MSG_NO_FIELDS' => 'Nenhum Campo Disponível',

//Customization Phase 6 -- Monolithic
'LBL_REPORTCHARTS' => 'Gráficos Relatórios',
'LBL_HOME_REPORT_NAME'=> 'Nome Relatório',
'LBL_HOME_REPORT_TYPE' => 'Tipo Relatório',
//END

//added for Default Widgets
'LBL_DEFAULT_WIDGET'=>'Widgets Padrão',
'LBL_NO_WIDGETS_HIDDEN'=>'Nenhum widgets padrão oculto',
);

?>
